@@ -10,6 +10,9 @@ def api_v4(self):
     user_load_balancing_analytics(self)
     user_tokens_verify(self)
 
+    # The API commands for /radar/
+    radar(self)
+
     # The API commands for /zones/
     zones(self)
     zones_access(self)
@@ -32,6 +35,7 @@ def api_v4(self):
     zones_waiting_rooms(self)
     zones_workers(self)
     zones_extras(self)
+    zones_web3(self)
     zones_email(self)
     zones_api_gateway(self)
 
@@ -114,7 +118,6 @@ def zones(self):
     self.add('AUTH', 'zones', 'security/events')
     self.add('AUTH', 'zones', 'subscription')
 
-
 def zones_settings(self):
     """ zones settings """
 
@@ -124,6 +127,7 @@ def zones_settings(self):
     self.add('AUTH', 'zones', 'settings/always_online')
     self.add('AUTH', 'zones', 'settings/always_use_https')
     self.add('AUTH', 'zones', 'settings/automatic_https_rewrites')
+    self.add('AUTH', 'zones', 'settings/automatic_platform_optimization')
     self.add('AUTH', 'zones', 'settings/brotli')
     self.add('AUTH', 'zones', 'settings/browser_cache_ttl')
     self.add('AUTH', 'zones', 'settings/browser_check')
@@ -131,6 +135,7 @@ def zones_settings(self):
     self.add('AUTH', 'zones', 'settings/challenge_ttl')
     self.add('AUTH', 'zones', 'settings/ciphers')
     self.add('AUTH', 'zones', 'settings/development_mode')
+    self.add('AUTH', 'zones', 'settings/early_hints')
     self.add('AUTH', 'zones', 'settings/email_obfuscation')
     self.add('AUTH', 'zones', 'settings/h2_prioritization')
     self.add('AUTH', 'zones', 'settings/hotlink_protection')
@@ -145,10 +150,13 @@ def zones_settings(self):
     self.add('AUTH', 'zones', 'settings/mobile_redirect')
     self.add('AUTH', 'zones', 'settings/opportunistic_encryption')
     self.add('AUTH', 'zones', 'settings/opportunistic_onion')
+    self.add('AUTH', 'zones', 'settings/orange_to_orange')
     self.add('AUTH', 'zones', 'settings/origin_error_page_pass_thru')
+    self.add('AUTH', 'zones', 'settings/origin_max_http_version')
     self.add('AUTH', 'zones', 'settings/polish')
     self.add('AUTH', 'zones', 'settings/prefetch_preload')
     self.add('AUTH', 'zones', 'settings/privacy_pass')
+    self.add('AUTH', 'zones', 'settings/proxy_read_timeout')
     self.add('AUTH', 'zones', 'settings/pseudo_ipv4')
     self.add('AUTH', 'zones', 'settings/response_buffering')
     self.add('AUTH', 'zones', 'settings/rocket_loader')
@@ -157,15 +165,13 @@ def zones_settings(self):
     self.add('AUTH', 'zones', 'settings/server_side_exclude')
     self.add('AUTH', 'zones', 'settings/sort_query_string_for_cache')
     self.add('AUTH', 'zones', 'settings/ssl')
+    self.add('AUTH', 'zones', 'settings/ssl_recommender')
     self.add('AUTH', 'zones', 'settings/tls_1_3')
     self.add('AUTH', 'zones', 'settings/tls_client_auth')
     self.add('AUTH', 'zones', 'settings/true_client_ip_header')
     self.add('AUTH', 'zones', 'settings/waf')
     self.add('AUTH', 'zones', 'settings/webp')
     self.add('AUTH', 'zones', 'settings/websockets')
-    self.add('AUTH', 'zones', 'settings/early_hints')
-    self.add('AUTH', 'zones', 'settings/proxy_read_timeout')
-    self.add('AUTH', 'zones', 'settings/ssl_recommender')
 
 def zones_analytics(self):
     """ zones analytics """
@@ -216,6 +222,8 @@ def zones_logpush(self):
     self.add('VOID', 'zones', 'logpush/datasets')
     self.add('AUTH', 'zones', 'logpush/datasets', 'fields')
     self.add('AUTH', 'zones', 'logpush/datasets', 'jobs')
+    self.add('VOID', 'zones', 'logpush/edge')
+    self.add('AUTH', 'zones', 'logpush/edge/jobs')
     self.add('AUTH', 'zones', 'logpush/jobs')
     self.add('AUTH', 'zones', 'logpush/ownership')
     self.add('AUTH', 'zones', 'logpush/ownership/validate')
@@ -360,30 +368,33 @@ def accounts(self):
     self.add('AUTH', 'accounts')
     self.add('VOID', 'accounts', 'billing')
     self.add('AUTH', 'accounts', 'billing/profile')
-
     self.add('AUTH', 'accounts', 'cfd_tunnel')
     self.add('AUTH', 'accounts', 'cfd_tunnel', 'configurations')
     self.add('AUTH', 'accounts', 'cfd_tunnel', 'connections')
     self.add('AUTH', 'accounts', 'cfd_tunnel', 'token')
-
     self.add('AUTH', 'accounts', 'custom_pages')
-
+    self.add('VOID', 'accounts', 'dlp')
+    self.add('VOID', 'accounts', 'dlp/patterns')
+    self.add('AUTH', 'accounts', 'dlp/patterns/validate')
+    self.add('AUTH', 'accounts', 'dlp/profiles')
+    self.add('AUTH', 'accounts', 'dlp/profiles/custom')
+    self.add('AUTH', 'accounts', 'dlp/profiles/predefined')
     self.add('AUTH', 'accounts', 'members')
-
+    self.add('VOID', 'accounts', 'mnm')
+    self.add('AUTH', 'accounts', 'mnm/config')
+    self.add('AUTH', 'accounts', 'mnm/config/full')
+    self.add('AUTH', 'accounts', 'mnm/rules')
+    self.add('AUTH', 'accounts', 'mnm/rules', 'advertisement')
     self.add('AUTH', 'accounts', 'railguns')
     self.add('AUTH', 'accounts', 'railguns', 'connections')
-
     self.add('VOID', 'accounts', 'registrar')
     self.add('AUTH', 'accounts', 'registrar/domains')
     self.add('AUTH', 'accounts', 'registrar/contacts')
-
     self.add('AUTH', 'accounts', 'roles')
-
     self.add('VOID', 'accounts', 'rules')
     self.add('AUTH', 'accounts', 'rules/lists')
     self.add('AUTH', 'accounts', 'rules/lists', 'items')
     self.add('AUTH', 'accounts', 'rules/lists/bulk_operations')
-
     self.add('AUTH', 'accounts', 'rulesets')
     self.add('AUTH', 'accounts', 'rulesets', 'versions')
     self.add('AUTH', 'accounts', 'rulesets', 'rules')
@@ -391,7 +402,6 @@ def accounts(self):
     self.add('VOID', 'accounts', 'rulesets/phases')
     self.add('AUTH', 'accounts', 'rulesets/phases', 'entrypoint')
     self.add('AUTH', 'accounts', 'rulesets/phases', 'entrypoint/versions')
-
     self.add('VOID', 'accounts', 'storage')
     self.add('AUTH', 'accounts', 'storage/analytics')
     self.add('AUTH', 'accounts', 'storage/analytics/stored')
@@ -401,17 +411,13 @@ def accounts(self):
     self.add('AUTH', 'accounts', 'storage/kv/namespaces', 'keys')
     self.add('AUTH', 'accounts', 'storage/kv/namespaces', 'values')
     self.add('AUTH', 'accounts', 'storage/kv/namespaces', 'metadata')
-
     self.add('AUTH', 'accounts', 'subscriptions')
-
     self.add('AUTH', 'accounts', 'tunnels')
     self.add('AUTH', 'accounts', 'tunnels', 'connections')
-
     self.add('AUTH', 'accounts', 'virtual_dns')
     self.add('VOID', 'accounts', 'virtual_dns', 'dns_analytics')
     self.add('AUTH', 'accounts', 'virtual_dns', 'dns_analytics/report')
     self.add('AUTH', 'accounts', 'virtual_dns', 'dns_analytics/report/bytime')
-
     self.add('VOID', 'accounts', 'workers')
     self.add('AUTH', 'accounts', 'workers/account-settings')
     self.add('AUTH', 'accounts', 'workers/domains')
@@ -428,6 +434,10 @@ def accounts_addressing(self):
     """ accounts addressing """
 
     self.add('VOID', 'accounts', 'addressing')
+    self.add('AUTH', 'accounts', 'addressing/address_maps')
+    self.add('AUTH', 'accounts', 'addressing/address_maps', 'accounts')
+    self.add('AUTH', 'accounts', 'addressing/address_maps', 'ips')
+    self.add('AUTH', 'accounts', 'addressing/address_maps', 'zones')
     self.add('AUTH', 'accounts', 'addressing/loa_documents')
     self.add('AUTH', 'accounts', 'addressing/loa_documents', 'download')
     self.add('AUTH', 'accounts', 'addressing/prefixes')
@@ -491,7 +501,6 @@ def accounts_stream(self):
     self.add('AUTH', 'accounts', 'stream/live_inputs', 'outputs')
     self.add('AUTH', 'accounts', 'stream/live_inputs', 'outputs', 'enabled')
 
-
 def zones_media(self):
     """ zones media """
 
@@ -527,7 +536,6 @@ def zones_access(self):
     self.add('AUTH', 'zones', 'access/organizations/revoke_user')
     self.add('AUTH', 'zones', 'access/service_tokens')
 
-
 def accounts_access(self):
     """ accounts access """
 
@@ -539,6 +547,7 @@ def accounts_access(self):
     self.add('AUTH', 'accounts', 'access/organizations/revoke_user')
     self.add('AUTH', 'accounts', 'access/service_tokens')
     self.add('AUTH', 'accounts', 'access/service_tokens', 'refresh')
+    self.add('AUTH', 'accounts', 'access/service_tokens', 'rotate')
     self.add('AUTH', 'accounts', 'access/apps')
 #   self.add('AUTH', 'accounts', 'access/apps/ca')
     self.add('AUTH', 'accounts', 'access/apps', 'ca')
@@ -566,6 +575,7 @@ def zones_waiting_rooms(self):
     self.add('AUTH', 'zones', 'waiting_rooms')
     self.add('AUTH', 'zones', 'waiting_rooms', 'events')
     self.add('AUTH', 'zones', 'waiting_rooms', 'events', 'details')
+    self.add('AUTH', 'zones', 'waiting_rooms', 'rules')
     self.add('AUTH', 'zones', 'waiting_rooms', 'status')
     self.add('AUTH', 'zones', 'waiting_rooms/preview')
 
@@ -588,10 +598,11 @@ def accounts_extras(self):
 
     self.add('AUTH', 'accounts', 'devices')
     self.add('AUTH', 'accounts', 'devices', 'override_codes')
-    self.add('VOID', 'accounts', 'devices/policy')
-    self.add('AUTH', 'accounts', 'devices/policy/exclude')
-    self.add('AUTH', 'accounts', 'devices/policy/fallback_domains')
-    self.add('AUTH', 'accounts', 'devices/policy/include')
+    self.add('AUTH', 'accounts', 'devices/policies')
+    self.add('AUTH', 'accounts', 'devices/policy')
+    self.add('AUTH', 'accounts', 'devices/policy', 'exclude')
+    self.add('AUTH', 'accounts', 'devices/policy', 'fallback_domains')
+    self.add('AUTH', 'accounts', 'devices/policy', 'include')
     self.add('AUTH', 'accounts', 'devices/posture')
     self.add('AUTH', 'accounts', 'devices/posture/integration')
     self.add('AUTH', 'accounts', 'devices/revoke')
@@ -667,11 +678,15 @@ def accounts_extras(self):
 def zones_extras(self):
     """ zones extras """
 
+    self.add('VOID', 'zones', 'acm')
+    self.add('AUTH', 'zones', 'acm/total_tls')
     self.add('VOID', 'zones', 'cache')
     self.add('AUTH', 'zones', 'cache/variants')
+    self.add('AUTH', 'zones', 'cache/cache_reserve')
     self.add('AUTH', 'zones', 'managed_headers')
     self.add('AUTH', 'zones', 'page_shield')
     self.add('AUTH', 'zones', 'page_shield/scripts')
+    self.add('AUTH', 'zones', 'page_shield/connections')
     self.add('AUTH', 'zones', 'rulesets')
     self.add('AUTH', 'zones', 'rulesets', 'rules')
     self.add('AUTH', 'zones', 'rulesets', 'versions')
@@ -680,11 +695,16 @@ def zones_extras(self):
     self.add('AUTH', 'zones', 'rulesets/phases', 'entrypoint/versions')
     self.add('VOID', 'zones', 'rulesets/phases/http_custom_errors')
     self.add('AUTH', 'zones', 'rulesets/phases/http_custom_errors/entrypoint')
-    self.add('AUTH', 'zones', 'settings/automatic_platform_optimization')
-    self.add('AUTH', 'zones', 'settings/orange_to_orange')
     self.add('AUTH', 'zones', 'url_normalization')
+
+def zones_web3(self):
+    """ zones web3 """
+
     self.add('VOID', 'zones', 'web3')
     self.add('AUTH', 'zones', 'web3/hostnames')
+    self.add('VOID', 'zones', 'web3/hostnames', 'ipfs_universal_path')
+    self.add('AUTH', 'zones', 'web3/hostnames', 'ipfs_universal_path/content_list')
+    self.add('AUTH', 'zones', 'web3/hostnames', 'ipfs_universal_path/content_list/entries')
 
 def accounts_email(self):
     """ accounts email """
@@ -718,5 +738,94 @@ def zones_api_gateway(self):
     self.add('VOID', 'zones', 'api_gateway')
     self.add('AUTH', 'zones', 'api_gateway/configuration')
     self.add('AUTH', 'zones', 'api_gateway/discovery')
+    self.add('AUTH', 'zones', 'api_gateway/operations')
+    self.add('AUTH', 'zones', 'api_gateway/schemas')
 
-
+def radar(self):
+    """ radar """
+    self.add('VOID', 'radar')
+    self.add('VOID', 'radar/annotations')
+    self.add('AUTH', 'radar/annotations/outages')
+    self.add('AUTH', 'radar/annotations/outages/locations')
+    self.add('VOID', 'radar/attacks')
+    self.add('VOID', 'radar/attacks/layer3')
+    self.add('AUTH', 'radar/attacks/layer3/summary')
+    self.add('AUTH', 'radar/attacks/layer3/timeseries')
+    self.add('AUTH', 'radar/attacks/layer3/timeseries_groups')
+    self.add('VOID', 'radar/attacks/layer7')
+    self.add('AUTH', 'radar/attacks/layer7/summary')
+    self.add('AUTH', 'radar/attacks/layer7/timeseries')
+    self.add('AUTH', 'radar/attacks/layer7/timeseries_groups')
+    self.add('VOID', 'radar/attacks/layer7/top')
+    self.add('VOID', 'radar/attacks/layer7/top/ases')
+    self.add('AUTH', 'radar/attacks/layer7/top/ases/origin')
+    self.add('AUTH', 'radar/attacks/layer7/top/attacks')
+    self.add('VOID', 'radar/attacks/layer7/top/locations')
+    self.add('AUTH', 'radar/attacks/layer7/top/locations/origin')
+    self.add('AUTH', 'radar/attacks/layer7/top/locations/target')
+    self.add('VOID', 'radar/bgp')
+    self.add('AUTH', 'radar/bgp/timeseries')
+    self.add('VOID', 'radar/bgp/top')
+    self.add('AUTH', 'radar/bgp/top/ases')
+    self.add('AUTH', 'radar/bgp/top/prefixes')
+    self.add('VOID', 'radar/dns')
+    self.add('AUTH', 'radar/dns/timeseries')
+    self.add('VOID', 'radar/dns/top')
+    self.add('AUTH', 'radar/dns/top/ases')
+    self.add('AUTH', 'radar/dns/top/locations')
+    self.add('VOID', 'radar/entities')
+    self.add('AUTH', 'radar/entities/asns')
+    self.add('AUTH', 'radar/entities/asns/ip')
+    self.add('AUTH', 'radar/entities/locations')
+    self.add('VOID', 'radar/http')
+    self.add('VOID', 'radar/http/summary')
+    self.add('AUTH', 'radar/http/summary/bot_class')
+    self.add('AUTH', 'radar/http/summary/device_type')
+    self.add('AUTH', 'radar/http/summary/http_protocol')
+    self.add('AUTH', 'radar/http/summary/http_version')
+    self.add('AUTH', 'radar/http/summary/ip_version')
+    self.add('AUTH', 'radar/http/summary/tls_version')
+    self.add('VOID', 'radar/http/timeseries')
+    self.add('AUTH', 'radar/http/timeseries/bot_class')
+    self.add('AUTH', 'radar/http/timeseries/browser')
+    self.add('AUTH', 'radar/http/timeseries/browser_family')
+    self.add('AUTH', 'radar/http/timeseries/device_type')
+    self.add('AUTH', 'radar/http/timeseries/http_protocol')
+    self.add('AUTH', 'radar/http/timeseries/http_version')
+    self.add('AUTH', 'radar/http/timeseries/ip_version')
+    self.add('AUTH', 'radar/http/timeseries/tls_version')
+    self.add('VOID', 'radar/http/top')
+    self.add('AUTH', 'radar/http/top/ases')
+    self.add('AUTH', 'radar/http/top/ases/bot_class')
+    self.add('AUTH', 'radar/http/top/ases/device_type')
+    self.add('AUTH', 'radar/http/top/ases/http_protocol')
+    self.add('AUTH', 'radar/http/top/ases/http_version')
+    self.add('AUTH', 'radar/http/top/ases/ip_version')
+    self.add('AUTH', 'radar/http/top/ases/tls_version')
+    self.add('AUTH', 'radar/http/top/browsers')
+    self.add('AUTH', 'radar/http/top/browser_families')
+    self.add('AUTH', 'radar/http/top/locations')
+    self.add('AUTH', 'radar/http/top/locations/bot_class')
+    self.add('AUTH', 'radar/http/top/locations/device_type')
+    self.add('AUTH', 'radar/http/top/locations/http_protocol')
+    self.add('AUTH', 'radar/http/top/locations/http_version')
+    self.add('AUTH', 'radar/http/top/locations/ip_version')
+    self.add('AUTH', 'radar/http/top/locations/tls_version')
+    self.add('VOID', 'radar/netflows')
+    self.add('AUTH', 'radar/netflows/timeseries')
+    self.add('VOID', 'radar/netflows/top')
+    self.add('AUTH', 'radar/netflows/top/ases')
+    self.add('AUTH', 'radar/netflows/top/locations')
+    self.add('VOID', 'radar/ranking')
+    self.add('AUTH', 'radar/ranking/timeseries')
+    self.add('AUTH', 'radar/ranking/top')
+    self.add('VOID', 'radar/reports')
+    self.add('AUTH', 'radar/reports/datasets')
+    self.add('AUTH', 'radar/reports/datasets/download')
+    self.add('VOID', 'radar/search')
+    self.add('AUTH', 'radar/search/global')
+    self.add('AUTH', 'radar/specialevents')
+    self.add('VOID', 'radar/verified_bots')
+    self.add('VOID', 'radar/verified_bots/top')
+    self.add('AUTH', 'radar/verified_bots/top/bots')
+    self.add('AUTH', 'radar/verified_bots/top/categories')
