@@ -34,6 +34,11 @@ def dump_commands_from_web(cf):
         else:
             sys.stdout.write('%-6s %s\n' % (r['action'], r['cmd']))
 
+def strip_multiline(s):
+    """ remove leading/trailing tabs/spaces on each line"""
+    # This hack is needed in order to use yaml.safe_load() on JSON text - tabs are not allowed
+    return '\n'.join([l.strip() for l in s.splitlines()])
+
 def run_command(cf, method, command, params=None, content=None, files=None):
     """run the command line"""
     # remove leading and trailing /'s
@@ -54,7 +59,7 @@ def run_command(cf, method, command, params=None, content=None, files=None):
 
     hex_only = re.compile('^[0-9a-fA-F]+$')
     waf_rules = re.compile('^[0-9]+[A-Z]*$')
-    uuid_value = re.compile('^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$')	# 8-4-4-4-12
+    uuid_value = re.compile('^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$') # 8-4-4-4-12
 
     m = cf
     for element in parts:
@@ -202,14 +207,14 @@ def run_command(cf, method, command, params=None, content=None, files=None):
             if len(e) > 0:
                 # more than one error returned by the API
                 for x in e:
-                    sys.stderr.write('cli4: /%s - %d %s\n' % (command, x, x))
-            sys.stderr.write('cli4: /%s - %d %s\n' % (command, int(e), e))
+                    sys.stderr.write('cli4: /%s - %d %s\n' % (command, int(x), str(x)))
+            sys.stderr.write('cli4: /%s - %d %s\n' % (command, int(e), str(e)))
             raise e
         except CloudFlare.exceptions.CloudFlareInternalError as e:
-            sys.stderr.write('cli4: InternalError: /%s - %d %s\n' % (command, int(e), e))
+            sys.stderr.write('cli4: InternalError: /%s - %d %s\n' % (command, int(e), str(e)))
             raise e
         except Exception as e:
-            sys.stderr.write('cli4: /%s - %s - api error\n' % (command, e))
+            sys.stderr.write('cli4: /%s - %s - api error\n' % (command, str(e)))
             raise e
 
         results.append(r)
@@ -403,6 +408,9 @@ def do_it(args):
                 #value = json.loads(value) - changed to yaml code to remove unicode string issues
                 if yaml is None:
                     sys.exit('cli4: install yaml support')
+                # cleanup string before parsing so that yaml.safe.load does not complain about whitespace
+                # >>> found character '\t' that cannot start any token <<<
+                value_string = strip_multiline(value_string)
                 try:
                     value = yaml.safe_load(value_string)
                 except yaml.parser.ParserError as e:
@@ -454,6 +462,7 @@ def do_it(args):
     except Exception as e:
         sys.exit(e)
 
+    exit_with_error = False
     for command in commands:
         try:
             results = run_command(cf, method, command, params, content, files)
@@ -461,9 +470,10 @@ def do_it(args):
         except KeyboardInterrupt as e:
             sys.exit('cli4: %s - Interrupted\n' % (command))
         except Exception as e:
-            if len(commands) > 1:
-                continue
-            sys.exit(e)
+            exit_with_error = True
+
+    if exit_with_error:
+        sys.exit(1)
 
 def cli4(args):
     """Cloudflare API via command line"""
